@@ -4,10 +4,11 @@
 import logging
 from collections import namedtuple
 
-from pyhocon import ConfigFactory, ConfigTree  # noqa: F401
-from typing import Iterator, Union, Dict, Any  # noqa: F401
+from pyhocon import ConfigFactory, ConfigTree
+from typing import Iterator, Union, Dict, Any
 
 from databuilder import Scoped
+from databuilder.extractor.table_metadata_constants import PARTITION_BADGE
 from databuilder.extractor.base_extractor import Extractor
 from databuilder.extractor.sql_alchemy_extractor import SQLAlchemyExtractor
 from databuilder.models.table_metadata import TableMetadata, ColumnMetadata
@@ -23,12 +24,13 @@ class HiveTableMetadataExtractor(Extractor):
     """
     Extracts Hive table and column metadata from underlying meta store database using SQLAlchemyExtractor
     """
+    EXTRACT_SQL = 'extract_sql'
     # SELECT statement from hive metastore database to extract table and column metadata
     # Below SELECT statement uses UNION to combining two queries together.
     # 1st query is retrieving partition columns
     # 2nd query is retrieving columns
     # Using UNION to combine above two statements and order by table & partition identifier.
-    SQL_STATEMENT = """
+    DEFAULT_SQL_STATEMENT = """
     SELECT source.* FROM
     (SELECT t.TBL_ID, d.NAME as `schema`, t.TBL_NAME name, t.TBL_TYPE, tp.PARAM_VALUE as description,
            p.PKEY_NAME as col_name, p.INTEGER_IDX as col_sort_order,
@@ -61,14 +63,15 @@ class HiveTableMetadataExtractor(Extractor):
     DEFAULT_CONFIG = ConfigFactory.from_dict({WHERE_CLAUSE_SUFFIX_KEY: ' ',
                                               CLUSTER_KEY: 'gold'})
 
-    def init(self, conf):
-        # type: (ConfigTree) -> None
+    def init(self, conf: ConfigTree) -> None:
         conf = conf.with_fallback(HiveTableMetadataExtractor.DEFAULT_CONFIG)
         self._cluster = '{}'.format(conf.get_string(HiveTableMetadataExtractor.CLUSTER_KEY))
 
-        self.sql_stmt = HiveTableMetadataExtractor.SQL_STATEMENT.format(
+        default_sql = HiveTableMetadataExtractor.DEFAULT_SQL_STATEMENT.format(
             where_clause_suffix=conf.get_string(HiveTableMetadataExtractor.WHERE_CLAUSE_SUFFIX_KEY))
 
+        self.sql_stmt = conf.get_string(HiveTableMetadataExtractor.EXTRACT_SQL, default=default_sql)
+
         LOGGER.info('SQL for hive metastore: {}'.format(self.sql_stmt))
 
         self._alchemy_extractor = SQLAlchemyExtractor()
@@ -76,10 +79,9 @@ class HiveTableMetadataExtractor(Extractor):
             .with_fallback(ConfigFactory.from_dict({SQLAlchemyExtractor.EXTRACT_SQL: self.sql_stmt}))
 
         self._alchemy_extractor.init(sql_alch_conf)
-        self._extract_iter = None  # type: Union[None, Iterator]
+        self._extract_iter: Union[None, Iterator] = None
 
-    def extract(self):
-        # type: () -> Union[TableMetadata, None]
+    def extract(self) -> Union[TableMetadata, None]:
         if not self._extract_iter:
             self._extract_iter = self._get_extract_iter()
         try:
@@ -87,12 +89,10 @@ class HiveTableMetadataExtractor(Extractor):
         except StopIteration:
             return None
 
-    def get_scope(self):
-        # type: () -> str
+    def get_scope(self) -> str:
         return 'extractor.hive_table_metadata'
 
-    def _get_extract_iter(self):
-        # type: () -> Iterator[TableMetadata]
+    def _get_extract_iter(self) -> Iterator[TableMetadata]:
         """
         Using itertools.groupby and raw level iterator, it groups to table and yields TableMetadata
         :return:
@@ -102,8 +102,15 @@ class HiveTableMetadataExtractor(Extractor):
 
             for row in group:
                 last_row = row
-                columns.append(ColumnMetadata(row['col_name'], row['col_description'],
-                                              row['col_type'], row['col_sort_order']))
+                column = None
+                if row['is_partition_col'] == 1:
+                    # create add a badge to indicate partition column
+                    column = ColumnMetadata(row['col_name'], row['col_description'],
+                                            row['col_type'], row['col_sort_order'], [PARTITION_BADGE])
+                else:
+                    column = ColumnMetadata(row['col_name'], row['col_description'],
+                                            row['col_type'], row['col_sort_order'])
+                columns.append(column)
             is_view = last_row['is_view'] == 1
             yield TableMetadata('hive', self._cluster,
                                 last_row['schema'],
@@ -112,8 +119,7 @@ class HiveTableMetadataExtractor(Extractor):
                                 columns,
                                 is_view=is_view)
 
-    def _get_raw_extract_iter(self):
-        # type: () -> Iterator[Dict[str, Any]]
+    def _get_raw_extract_iter(self) -> Iterator[Dict[str, Any]]:
         """
         Provides iterator of result row from SQLAlchemy extractor
         :return:
@@ -123,8 +129,7 @@ class HiveTableMetadataExtractor(Extractor):
             yield row
             row = self._alchemy_extractor.extract()
 
-    def _get_table_key(self, row):
-        # type: (Dict[str, Any]) -> Union[TableKey, None]
+    def _get_table_key(self, row: Dict[str, Any]) -> Union[TableKey, None]:
         """
         Table key consists of schema and table name
         :param row:
