@@ -1,7 +1,7 @@
 # Copyright Contributors to the Amundsen project.
 # SPDX-License-Identifier: Apache-2.0
 
-from typing import Iterable, Union, Dict, Any, Iterator  # noqa: F401
+from typing import Iterable, Union, Dict, Any, Iterator
 
 from databuilder.models.neo4j_csv_serde import (
     Neo4jCsvSerializable, RELATION_START_KEY, RELATION_END_KEY,
@@ -18,15 +18,14 @@ class ColumnReader(object):
     """
 
     def __init__(self,
-                 database,  # type: str
-                 cluster,  # type: str
-                 schema,  # type: str
-                 table,  # type: str
-                 column,  # type: str
-                 user_email,  # type: str
-                 read_count=1  # type: int
-                 ):
-        # type: (...) -> None
+                 database: str,
+                 cluster: str,
+                 schema: str,
+                 table: str,
+                 column: str,
+                 user_email: str,
+                 read_count: int = 1
+                 ) -> None:
         self.database = database.lower()
         self.cluster = cluster.lower()
         self.schema = schema.lower()
@@ -35,8 +34,7 @@ class ColumnReader(object):
         self.user_email = user_email.lower()
         self.read_count = read_count
 
-    def __repr__(self):
-        # type: () -> str
+    def __repr__(self) -> str:
         return """\
 ColumnReader(database={!r}, cluster={!r}, schema={!r}, table={!r}, column={!r}, user_email={!r}, read_count={!r})"""\
             .format(self.database, self.cluster, self.schema, self.table, self.column, self.user_email, self.read_count)
@@ -57,9 +55,8 @@ class TableColumnUsage(Neo4jCsvSerializable):
     READ_RELATION_COUNT = 'read_count{}'.format(UNQUOTED_SUFFIX)
 
     def __init__(self,
-                 col_readers,  # type: Iterable[ColumnReader]
-                 ):
-        # type: (...) -> None
+                 col_readers: Iterable[ColumnReader],
+                 ) -> None:
         for col_reader in col_readers:
             if col_reader.column != '*':
                 raise NotImplementedError('Column is not supported yet {}'.format(col_readers))
@@ -68,31 +65,27 @@ class TableColumnUsage(Neo4jCsvSerializable):
         self._node_iterator = self._create_node_iterator()
         self._rel_iter = self._create_rel_iterator()
 
-    def create_next_node(self):
-        # type: () -> Union[Dict[str, Any], None]
+    def create_next_node(self) -> Union[Dict[str, Any], None]:
 
         try:
             return next(self._node_iterator)
         except StopIteration:
             return None
 
-    def _create_node_iterator(self):
-        # type: () -> Iterator[Any]
+    def _create_node_iterator(self) -> Iterator[Any]:
         for col_reader in self.col_readers:
             if col_reader.column == '*':
                 # using yield for better memory efficiency
                 yield User(email=col_reader.user_email).create_nodes()[0]
 
-    def create_next_relation(self):
-        # type: () -> Union[Dict[str, Any], None]
+    def create_next_relation(self) -> Union[Dict[str, Any], None]:
 
         try:
             return next(self._rel_iter)
         except StopIteration:
             return None
 
-    def _create_rel_iterator(self):
-        # type: () -> Iterator[Any]
+    def _create_rel_iterator(self) -> Iterator[Any]:
         for col_reader in self.col_readers:
             yield {
                 RELATION_START_LABEL: TableMetadata.TABLE_NODE_LABEL,
@@ -104,17 +97,14 @@ class TableColumnUsage(Neo4jCsvSerializable):
                 TableColumnUsage.READ_RELATION_COUNT: col_reader.read_count
             }
 
-    def _get_table_key(self, col_reader):
-        # type: (ColumnReader) -> str
+    def _get_table_key(self, col_reader: ColumnReader) -> str:
         return TableMetadata.TABLE_KEY_FORMAT.format(db=col_reader.database,
                                                      cluster=col_reader.cluster,
                                                      schema=col_reader.schema,
                                                      tbl=col_reader.table)
 
-    def _get_user_key(self, email):
-        # type: (str) -> str
+    def _get_user_key(self, email: str) -> str:
         return User.get_user_model_key(email=email)
 
-    def __repr__(self):
-        # type: () -> str
+    def __repr__(self) -> str:
         return 'TableColumnUsage(col_readers={!r})'.format(self.col_readers)
