@@ -12,6 +12,7 @@ from databuilder.models.neo4j_csv_serde import (
     RELATION_END_LABEL, RELATION_TYPE, RELATION_REVERSE_TYPE)
 from databuilder.publisher.neo4j_csv_publisher import UNQUOTED_SUFFIX
 from databuilder.models.schema import schema_constant
+from databuilder.models.badge import BadgeMetadata, Badge
 
 DESCRIPTION_NODE_LABEL_VAL = 'Description'
 DESCRIPTION_NODE_LABEL = DESCRIPTION_NODE_LABEL_VAL
@@ -43,7 +44,7 @@ class TagMetadata(Neo4jCsvSerializable):
 
     @staticmethod
     def create_tag_node(name: str,
-                        tag_type: str =DEFAULT_TYPE
+                        tag_type: str = DEFAULT_TYPE
                         ) -> Dict[str, str]:
         return {NODE_LABEL: TagMetadata.TAG_NODE_LABEL,
                 NODE_KEY: TagMetadata.get_tag_key(name),
@@ -150,16 +151,12 @@ class ColumnMetadata:
     COLUMN_DESCRIPTION = 'description'
     COLUMN_DESCRIPTION_FORMAT = '{db}://{cluster}.{schema}/{tbl}/{col}/{description_id}'
 
-    # Relation between column and tag
-    COL_TAG_RELATION_TYPE = 'TAGGED_BY'
-    TAG_COL_RELATION_TYPE = 'TAG'
-
     def __init__(self,
                  name: str,
                  description: Union[str, None],
                  col_type: str,
                  sort_order: int,
-                 tags: Union[List[str], None] = None
+                 badges: Union[List[str], None] = None
                  ) -> None:
         """
         TODO: Add stats
@@ -173,13 +170,17 @@ class ColumnMetadata:
                                                                            text=description)
         self.type = col_type
         self.sort_order = sort_order
-        self.tags = tags
+        if badges:
+            self.badges = [Badge(badge, 'column') for badge in badges]
+        else:
+            self.badges = []
 
     def __repr__(self) -> str:
-        return 'ColumnMetadata({!r}, {!r}, {!r}, {!r})'.format(self.name,
-                                                               self.description,
-                                                               self.type,
-                                                               self.sort_order)
+        return 'ColumnMetadata({!r}, {!r}, {!r}, {!r}, {!r})'.format(self.name,
+                                                                     self.description,
+                                                                     self.type,
+                                                                     self.sort_order,
+                                                                     self.badges)
 
 
 # Tuples for de-dupe purpose on Database, Cluster, Schema. See TableMetadata docstring for more information
@@ -313,7 +314,8 @@ class TableMetadata(Neo4jCsvSerializable):
                                                        cluster=self.cluster,
                                                        schema=self.schema,
                                                        tbl=self.name,
-                                                       col=col.name)
+                                                       col=col.name,
+                                                       badges=col.badges)
 
     def _get_col_description_key(self,
                                  col: ColumnMetadata,
@@ -375,11 +377,16 @@ class TableMetadata(Neo4jCsvSerializable):
                 node_key = self._get_col_description_key(col, col.description)
                 yield col.description.get_node_dict(node_key)
 
-            if col.tags:
-                for tag in col.tags:
-                    yield {NODE_LABEL: TagMetadata.TAG_NODE_LABEL,
-                           NODE_KEY: TagMetadata.get_tag_key(tag),
-                           TagMetadata.TAG_TYPE: 'default'}
+            if col.badges:
+                badge_metadata = BadgeMetadata(db_name=self._get_database_key(),
+                                               schema=self._get_schema_key(),
+                                               start_label=ColumnMetadata.COLUMN_NODE_LABEL,
+                                               start_key=self._get_col_key(col),
+                                               badges=col.badges,
+                                               cluster=self._get_cluster_key())
+                badge_nodes = badge_metadata.create_nodes()
+                for node in badge_nodes:
+                    yield node
 
         # Database, cluster, schema
         others = [NodeTuple(key=self._get_database_key(),
@@ -449,17 +456,16 @@ class TableMetadata(Neo4jCsvSerializable):
                 yield col.description.get_relation(ColumnMetadata.COLUMN_NODE_LABEL,
                                                    self._get_col_key(col),
                                                    self._get_col_description_key(col, col.description))
-
-            if col.tags:
-                for tag in col.tags:
-                    yield {
-                        RELATION_START_LABEL: TableMetadata.TABLE_NODE_LABEL,
-                        RELATION_END_LABEL: TagMetadata.TAG_NODE_LABEL,
-                        RELATION_START_KEY: self._get_table_key(),
-                        RELATION_END_KEY: TagMetadata.get_tag_key(tag),
-                        RELATION_TYPE: ColumnMetadata.COL_TAG_RELATION_TYPE,
-                        RELATION_REVERSE_TYPE: ColumnMetadata.TAG_COL_RELATION_TYPE,
-                    }
+            if col.badges:
+                badge_metadata = BadgeMetadata(db_name=self._get_database_key(),
+                                               schema=self._get_schema_key(),
+                                               start_label=ColumnMetadata.COLUMN_NODE_LABEL,
+                                               start_key=self._get_col_key(col),
+                                               badges=col.badges,
+                                               cluster=self._get_cluster_key())
+                badge_relations = badge_metadata.create_relation()
+                for relation in badge_relations:
+                    yield relation
 
         others = [
             RelTuple(start_label=TableMetadata.DATABASE_NODE_LABEL,
