@@ -5,11 +5,12 @@ import json
 import logging
 
 from elasticsearch.exceptions import NotFoundError
-from pyhocon import ConfigTree  # noqa: F401
-from typing import List  # noqa: F401
+from pyhocon import ConfigTree
+from typing import List
+
+from amundsen_common.models.index_map import TABLE_INDEX_MAP as TABLE_ELASTICSEARCH_INDEX_MAPPING
 
 from databuilder.publisher.base_publisher import Publisher
-from databuilder.publisher.elasticsearch_constants import TABLE_ELASTICSEARCH_INDEX_MAPPING
 
 LOGGER = logging.getLogger(__name__)
 
@@ -37,12 +38,10 @@ class ElasticsearchPublisher(Publisher):
 
     DEFAULT_ELASTICSEARCH_INDEX_MAPPING = TABLE_ELASTICSEARCH_INDEX_MAPPING
 
-    def __init__(self):
-        # type: () -> None
+    def __init__(self) -> None:
         super(ElasticsearchPublisher, self).__init__()
 
-    def init(self, conf):
-        # type: (ConfigTree) -> None
+    def init(self, conf: ConfigTree) -> None:
         self.conf = conf
 
         self.file_path = self.conf.get_string(ElasticsearchPublisher.FILE_PATH_CONFIG_KEY)
@@ -59,8 +58,7 @@ class ElasticsearchPublisher(Publisher):
                                                       10000)
         self.file_handler = open(self.file_path, self.file_mode)
 
-    def _fetch_old_index(self):
-        # type: () -> List[str]
+    def _fetch_old_index(self) -> List[str]:
         """
         Retrieve all indices that currently have {elasticsearch_alias} alias
         :return: list of elasticsearch indices
@@ -74,8 +72,7 @@ class ElasticsearchPublisher(Publisher):
             # return empty list on exception
             return []
 
-    def publish_impl(self):
-        # type: () -> None
+    def publish_impl(self) -> None:
         """
         Use Elasticsearch Bulk API to load data from file to a {new_index}.
         After upload, swap alias from {old_index} to {new_index} in a atomic operation
@@ -126,6 +123,5 @@ class ElasticsearchPublisher(Publisher):
         # perform alias update and index delete in single atomic operation
         self.elasticsearch_client.indices.update_aliases(update_action)
 
-    def get_scope(self):
-        # type: () -> str
+    def get_scope(self) -> str:
         return 'publisher.elasticsearch'
